Learn R Programming

fourPNO (version 1.0.4)

update_WKappaZ_NA: Update Lower and Upper Asymptote Parameters of 4PNO

Description

Internal function to update item lower and upper asymptote

Usage

update_WKappaZ_NA(Y, Ysum, Z, as, bs, gs, ss, theta, Kaps, alpha_c, beta_c,
  alpha_s, beta_s, gwg_reps)

Arguments

Y

A N by J matrix of item responses.

Ysum

A vector of item total scores.

Z

A matrix N by J of continuous augmented data.

as

A vector of item discrimination parameters.

bs

A vector of item threshold parameters.

gs

A vector of item lower asymptote parameters.

ss

A vector of item upper asymptote parameters.

theta

A vector of prior thetas.

Kaps

A matrix for item thresholds (used for internal computations).

alpha_c

The lower asymptote prior 'a' parameter.

beta_c

The lower asymptote prior 'b' parameter.

alpha_s

The upper asymptote prior 'a' parameter.

beta_s

The upper asymptote prior 'b' parameter.

gwg_reps

The number of Gibbs within Gibbs MCMC samples for marginal distribution of gamma.

Value

A list of item threshold parameters.

See Also

Gibbs_4PNO