Learn R Programming

fourPNO (version 1.0.4)

update_ab_NA: Update a and b Parameters of 2PNO, 3PNO, 4PNO

Description

Update item slope and threshold

Usage

update_ab_NA(N, J, Z, as, bs, theta, mu_xi, Sigma_xi_inv)

Arguments

N

An int, which gives the number of observations. (> 0)

J

An int, which gives the number of items. (> 0)

Z

A matrix N by J of continuous augmented data.

as

A vector of item discrimination parameters.

bs

A vector of item threshold parameters.

theta

A vector of prior thetas.

mu_xi

A two dimensional vector of prior item parameter means.

Sigma_xi_inv

A two dimensional identity matrix of prior item parameter VC matrix.

Value

A list of item parameters.

See Also

Gibbs_4PNO