Internal function to update item lower and upper asymptote
update_WKappaZ_NA(Y, Ysum, Z, as, bs, gs, ss, theta, Kaps, alpha_c, beta_c,
alpha_s, beta_s, gwg_reps)A N by J matrix of item responses.
A vector of item total scores.
A matrix N by J of continuous augmented data.
A vector of item discrimination parameters.
A vector of item threshold parameters.
A vector of item lower asymptote parameters.
A vector of item upper asymptote parameters.
A vector of prior thetas.
A matrix for item thresholds (used for internal computations).
The lower asymptote prior 'a' parameter.
The lower asymptote prior 'b' parameter.
The upper asymptote prior 'a' parameter.
The upper asymptote prior 'b' parameter.
The number of Gibbs within Gibbs MCMC samples for marginal distribution of gamma.
A list of item threshold parameters.