Update item slope and threshold
update_ab_NA(N, J, Z, as, bs, theta, mu_xi, Sigma_xi_inv)An int, which gives the number of observations. (> 0)
An int, which gives the number of items. (> 0)
A matrix N by J of continuous augmented data.
A vector of item discrimination parameters.
A vector of item threshold parameters.
A vector of prior thetas.
A two dimensional vector of prior item parameter means.
A two dimensional identity matrix of prior item parameter VC matrix.
A list of item parameters.